betty.ancestry.presence module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.presence module

Data types for people’s presences at events.

final class betty.ancestry.presence.Presence

  Bases: `ShorthandPluginBase`, `HasPrivacy`, `Entity`

  The presence of a `betty.ancestry.person.Person` at an `betty.ancestry.event.Event`.

  __init__(person: Person | ToOneResolver[Person], role: PresenceRole, event: Event | ToOneResolver[Event], *, privacy: Privacy | None = None, public: bool | None = None, private: bool | None = None)
  async dump_linked_data(project: Project) → DumpMapping[Dump]

    Dump this instance to JSON-LD.

  event

    The event the person was present at.

  property label: Localizable

    The entity’s human-readable label.

  async classmethod linked_data_schema(project: Project) → JsonLdObject

    Define the JSON Schema for `betty.json.linked_data.LinkedDataDumpable.dump_linked_data()`.

  person

    The person whose presence is described.

  classmethod plugin_label_plural() → Localizable

    The human-readable entity type label, plural.

  role: PresenceRole

    The role the person performed at the event.